---
title: Variables
---

### Variables

Variables are fields on a group entry that can be used to store information to use throughout your website or application.

#### Variable Repository

This class will go over the `\Anomaly\VariablesModule\Variable\Contract\VariableRepositoryInterface`

##### VariableRepositoryInterface::get()

The `get` method returns the raw data for the `variable` specified in a given `group`.

###### Returns: `mixed`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$group

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The slug of the group you want to access.

</td>

</tr>

<tr>

<td>

$field

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The slug of the variable field in the group you want to access.

</td>

</tr>

</tbody>

</table>

###### Example

    $variables->get('social', 'facebook_url'); // https://facebook.com/pyrocms

##### VariableRepositoryInterface::presenter()

The `presenter` method returns the field type presenter for the `variable` specified in a given `group`.

###### Returns: `\Anomaly\Streams\Platform\Addon\FieldType\FieldTypePresenter` or `null`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$group

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The slug of the group you want to access.

</td>

</tr>

<tr>

<td>

$field

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The slug of the variable field in the group you want to access.

</td>

</tr>

</tbody>

</table>

###### Example

    $variables->presenter('social', 'facebook_url')->link('Facebook'); // <a href="https://facebook.com/pyrocms">Facebook</a>

##### VariableRepositoryInterface::group()

The `group` method returns the entire `group` entry model so you can then easily access any `variable` on said model.

###### Returns: `\Anomaly\Streams\Platform\Entry\Contract\EntryInterface` or `null`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$group

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The slug of the group you want to access.

</td>

</tr>

</tbody>

</table>

###### Example

    $group = $variables->group('social');

    echo $group->facebook_url; // https://facebook.com/pyrocms
    echo $group->twitter_url; // https://twitter.com/pyrocms

    echo $group->getFieldTypePresenter('facebook_url')->link('Facebook'); // <a href="https://facebook.com/pyrocms">Facebook</a>
